@@ -34,19 +34,30 @@
 #define S2N_PEM_CERTIFICATE           "CERTIFICATE"
 #define S2N_PEM_CRL                   "X509 CRL"
 
-static int s2n_stuffer_pem_read_encapsulation_line(struct s2n_stuffer *pem, const char *encap_marker,
-        const char *keyword)
+static S2N_RESULT s2n_stuffer_pem_read_delimiter_chars(struct s2n_stuffer *pem)
 {
-    /* Skip any number of Chars until a "--" is reached.
+    RESULT_ENSURE_REF(pem);
+    RESULT_ENSURE(s2n_stuffer_data_available(pem) >= S2N_PEM_DELIMITER_MIN_COUNT,
+            S2N_ERR_INVALID_PEM);
+
+    /* Skip any number of chars until a "--" is reached.
      * We use "--" instead of "-" to account for dashes that appear in comments.
      * We do not accept comments that contain "--".
      */
-    POSIX_GUARD(s2n_stuffer_skip_read_until(pem, S2N_PEM_DELIMITER_TOKEN));
-    POSIX_GUARD(s2n_stuffer_rewind_read(pem, strlen(S2N_PEM_DELIMITER_TOKEN)));
+    RESULT_GUARD_POSIX(s2n_stuffer_skip_read_until(pem, S2N_PEM_DELIMITER_TOKEN));
+    RESULT_GUARD_POSIX(s2n_stuffer_rewind_read(pem, strlen(S2N_PEM_DELIMITER_TOKEN)));
 
     /* Ensure between 2 and 64 '-' chars at start of line. */
-    POSIX_GUARD(s2n_stuffer_skip_expected_char(pem, S2N_PEM_DELIMITER_CHAR, S2N_PEM_DELIMITER_MIN_COUNT,
-            S2N_PEM_DELIMITER_MAX_COUNT, NULL));
+    RESULT_GUARD_POSIX(s2n_stuffer_skip_expected_char(pem, S2N_PEM_DELIMITER_CHAR,
+            S2N_PEM_DELIMITER_MIN_COUNT, S2N_PEM_DELIMITER_MAX_COUNT, NULL));
+
+    return S2N_RESULT_OK;
+}
+
+static int s2n_stuffer_pem_read_encapsulation_line(struct s2n_stuffer *pem, const char *encap_marker,
+        const char *keyword)
+{
+    POSIX_GUARD_RESULT(s2n_stuffer_pem_read_delimiter_chars(pem));
 
     /* Ensure next string in stuffer is "BEGIN " or "END " */
     POSIX_GUARD(s2n_stuffer_read_expected_str(pem, encap_marker));
@@ -133,14 +144,14 @@ static int s2n_stuffer_data_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer
     return S2N_SUCCESS;
 }
 
-int s2n_stuffer_private_key_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer *asn1, int *type)
+int s2n_stuffer_private_key_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer *asn1, int *type_hint)
 {
     POSIX_PRECONDITION(s2n_stuffer_validate(pem));
     POSIX_PRECONDITION(s2n_stuffer_validate(asn1));
-    POSIX_ENSURE_REF(type);
+    POSIX_ENSURE_REF(type_hint);
 
     if (s2n_stuffer_data_from_pem(pem, asn1, S2N_PEM_PKCS1_RSA_PRIVATE_KEY) == S2N_SUCCESS) {
-        *type = EVP_PKEY_RSA;
+        *type_hint = EVP_PKEY_RSA;
         return S2N_SUCCESS;
     }
 
@@ -158,7 +169,7 @@ int s2n_stuffer_private_key_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer
     POSIX_GUARD(s2n_stuffer_wipe(asn1));
 
     if (s2n_stuffer_data_from_pem(pem, asn1, S2N_PEM_PKCS1_EC_PRIVATE_KEY) == S2N_SUCCESS) {
-        *type = EVP_PKEY_EC;
+        *type_hint = EVP_PKEY_EC;
         return S2N_SUCCESS;
     }
 
@@ -166,13 +177,29 @@ int s2n_stuffer_private_key_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer
     POSIX_GUARD(s2n_stuffer_reread(pem));
     POSIX_GUARD(s2n_stuffer_reread(asn1));
     if (s2n_stuffer_data_from_pem(pem, asn1, S2N_PEM_PKCS8_PRIVATE_KEY) == S2N_SUCCESS) {
-        *type = EVP_PKEY_RSA;
+        /* This is the most generic format, and could represent keys other than RSA.
+         * We set RSA only as a default type hint.
+         */
+        *type_hint = EVP_PKEY_RSA;
         return S2N_SUCCESS;
     }
 
     POSIX_BAIL(S2N_ERR_INVALID_PEM);
 }
 
+/* We define a pem containing a certificate as a pem containing the delimiter chars.
+ * If the delimiter chars exist but the certificate keyword doesn't, that is a parsing error.
+ * That ensures that we don't ignore unexpected keywords like "END CERTIFICATE"
+ * instead of "BEGIN CERTIFICATE" or malformed keywords like "BEGAN CERTIFICATE"
+ * instead of "BEGIN CERTIFICATE".
+ */
+bool s2n_stuffer_pem_has_certificate(struct s2n_stuffer *pem)
+{
+    /* Operate on a copy of pem to avoid modifying pem */
+    struct s2n_stuffer pem_copy = *pem;
+    return s2n_result_is_ok(s2n_stuffer_pem_read_delimiter_chars(&pem_copy));
+}
+
 int s2n_stuffer_certificate_from_pem(struct s2n_stuffer *pem, struct s2n_stuffer *asn1)
 {
     return s2n_stuffer_data_from_pem(pem, asn1, S2N_PEM_CERTIFICATE);
