@@ -250,9 +250,8 @@ class S2N(Provider):
             cmd_line.append("s2nc")
         cmd_line.append("--non-blocking")
 
-        # Tests requiring reconnects can't wait on echo data,
-        # but all other tests can.
-        if self.options.reconnect is not True:
+        # Tests requiring reconnects can't wait on echo data
+        if self.options.echo and not self.options.reconnect:
             cmd_line.append("-e")
 
         if self.options.use_session_ticket is False:
@@ -336,6 +335,9 @@ class S2N(Provider):
 
         cmd_line.extend(["-c", cipher_prefs])
 
+        if not self.options.echo:
+            cmd_line.append("-n")
+
         if self.options.use_client_auth is True:
             cmd_line.append("-m")
 
@@ -876,11 +878,10 @@ class GnuTLS(Provider):
             "--port",
             str(self.options.port),
             self.options.host,
-            "--debug",
-            "9999",
         ]
 
-        if self.options.verbose:
+        # Most GnuTLS tests expect verbose output, so default to True.
+        if self.options.verbose is not False:
             cmd_line.append("--verbose")
 
         if self.options.cert and self.options.key:
@@ -911,7 +912,6 @@ class GnuTLS(Provider):
             "gnutls-serv",
             f"--port={self.options.port}",
             "--echo",
-            "--debug=9999",
         ]
 
         if self.options.cert is not None:
