@@ -4,7 +4,7 @@ import pytest
 
 from configuration import available_ports, ALL_TEST_CIPHERS, ALL_TEST_CURVES, PROTOCOLS
 from common import ProviderOptions, data_bytes, Certificates
-from fixtures import managed_process  # lgtm [py/unused-import]
+from fixtures import managed_process  # noqa: F401
 from constants import TEST_OCSP_DIRECTORY
 from providers import Provider, S2N, OpenSSL, GnuTLS
 from utils import invalid_test_parameters, get_parameter_name
@@ -22,7 +22,13 @@ OCSP_CERTS = [Certificates.OCSP, Certificates.OCSP_ECDSA]
 @pytest.mark.parametrize("protocol", PROTOCOLS, ids=get_parameter_name)
 @pytest.mark.parametrize("certificate", OCSP_CERTS, ids=get_parameter_name)
 def test_s2n_client_ocsp_response(
-    managed_process, cipher, provider, other_provider, curve, protocol, certificate
+    managed_process,  # noqa: F811
+    cipher,
+    provider,
+    other_provider,
+    curve,
+    protocol,
+    certificate,
 ):
     if "boringssl" in get_flag(S2N_PROVIDER_VERSION):
         pytest.skip("s2n-tls client with boringssl does not support ocsp")
@@ -86,7 +92,13 @@ def test_s2n_client_ocsp_response(
 @pytest.mark.parametrize("protocol", PROTOCOLS, ids=get_parameter_name)
 @pytest.mark.parametrize("certificate", OCSP_CERTS, ids=get_parameter_name)
 def test_s2n_server_ocsp_response(
-    managed_process, cipher, provider, other_provider, curve, protocol, certificate
+    managed_process,  # noqa: F811
+    cipher,
+    provider,
+    other_provider,
+    curve,
+    protocol,
+    certificate,
 ):
     port = next(available_ports)
 
