@@ -88,7 +88,7 @@ S2N_RESULT s2n_connection_set_test_early_secret(struct s2n_connection *conn, con
 S2N_RESULT s2n_connection_set_test_handshake_secret(struct s2n_connection *conn, const struct s2n_blob *handshake_secret);
 S2N_RESULT s2n_connection_set_test_master_secret(struct s2n_connection *conn, const struct s2n_blob *master_secret);
 
-#define S2N_MAX_TEST_PEM_SIZE        8192
+#define S2N_MAX_TEST_PEM_SIZE        12000
 #define S2N_MAX_TEST_PEM_PATH_LENGTH 512
 
 /* These paths assume that the unit tests are run from inside the unit/ directory.
@@ -116,6 +116,9 @@ S2N_RESULT s2n_connection_set_test_master_secret(struct s2n_connection *conn, co
 #define S2N_RSA_PSS_2048_SHA256_LEAF_KEY  "../pems/rsa_pss_2048_sha256_leaf_key.pem"
 #define S2N_RSA_PSS_2048_SHA256_LEAF_CERT "../pems/rsa_pss_2048_sha256_leaf_cert.pem"
 
+#define S2N_MLDSA87_KEY  "../pems/mldsa/ML-DSA-87-seed.priv"
+#define S2N_MLDSA87_CERT "../pems/mldsa/ML-DSA-87.crt"
+
 #define S2N_RSA_2048_SHA256_CLIENT_CERT "../pems/rsa_2048_sha256_client_cert.pem"
 
 #define S2N_RSA_2048_SHA256_NO_DNS_SANS_CERT "../pems/rsa_2048_sha256_no_dns_sans_cert.pem"
@@ -249,20 +252,6 @@ S2N_RESULT s2n_test_new_iovecs(struct s2n_test_iovecs *iovecs,
         struct s2n_blob *data, const size_t *lens, size_t lens_count);
 S2N_CLEANUP_RESULT s2n_test_iovecs_free(struct s2n_test_iovecs *in);
 
-struct s2n_kem_kat_test_vector {
-    const struct s2n_kem *kem;
-    const char *kat_file;
-    bool (*asm_is_enabled)();
-    S2N_RESULT (*enable_asm)();
-    S2N_RESULT (*disable_asm)();
-};
-S2N_RESULT s2n_pq_kem_kat_test(const struct s2n_kem_kat_test_vector *test_vectors, size_t count);
-int s2n_test_hybrid_ecdhe_kem_with_kat(const struct s2n_kem *kem, struct s2n_cipher_suite *cipher_suite,
-        const char *cipher_pref_version, const char *kat_file_name, uint32_t server_key_message_length,
-        uint32_t client_key_message_length);
-S2N_RESULT s2n_pq_noop_asm();
-bool s2n_pq_no_asm_available();
-
 /* Expects 2 s2n_blobs to be equal (same size and contents) */
 #define S2N_BLOB_EXPECT_EQUAL(blob1, blob2)                         \
     do {                                                            \
