@@ -26,7 +26,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "crypto/s2n_openssl.h"
+#include "crypto/s2n_libcrypto.h"
 #include "s2n_test.h"
 
 #define MAX_LIBCRYPTO_NAME_LEN 100
@@ -73,33 +73,35 @@ S2N_RESULT s2n_check_supported_libcrypto(const char *s2n_libcrypto)
     const struct {
         const char *libcrypto;
         bool is_openssl;
+        bool is_opensslfips;
     } supported_libcrypto[] = {
         { .libcrypto = "awslc", .is_openssl = false },
         { .libcrypto = "awslc-fips", .is_openssl = false },
         { .libcrypto = "awslc-fips-2022", .is_openssl = false },
+        { .libcrypto = "awslc-fips-2024", .is_openssl = false },
         { .libcrypto = "boringssl", .is_openssl = false },
         { .libcrypto = "libressl", .is_openssl = false },
         { .libcrypto = "openssl-1.0.2", .is_openssl = true },
         { .libcrypto = "openssl-1.0.2-fips", .is_openssl = true },
         { .libcrypto = "openssl-1.1.1", .is_openssl = true },
         { .libcrypto = "openssl-3.0", .is_openssl = true },
+        { .libcrypto = "openssl-3.0-fips", .is_openssl = true, .is_opensslfips = true },
     };
 
     for (size_t i = 0; i < s2n_array_len(supported_libcrypto); i++) {
-        /* The linked libcryto is one of the known supported libcrypto variants */
-        if (strcmp(s2n_libcrypto, supported_libcrypto[i].libcrypto) == 0) {
-            if (supported_libcrypto[i].is_openssl) {
-                EXPECT_TRUE(s2n_libcrypto_is_openssl());
-            } else {
-                EXPECT_FALSE(s2n_libcrypto_is_openssl());
-            }
-
-            return S2N_RESULT_OK;
+        if (strcmp(s2n_libcrypto, supported_libcrypto[i].libcrypto) != 0) {
+            continue;
         }
+        EXPECT_EQUAL(s2n_libcrypto_is_openssl(), supported_libcrypto[i].is_openssl);
+        EXPECT_EQUAL(s2n_libcrypto_is_openssl_fips(), supported_libcrypto[i].is_opensslfips);
+        return S2N_RESULT_OK;
     }
 
-    /* Testing with an unexpected libcrypto. */
-    return S2N_RESULT_ERROR;
+    /* Fail if no matching libcrypto was found.
+     * Since we check for openssl via process of elimination, we must know
+     * and test the full list of non-openssl libcryptos.
+     */
+    FAIL_MSG("Unknown libcrypto - update supported_libcrypto list");
 }
 
 int main()
@@ -120,23 +122,19 @@ int main()
 
     if (s2n_libcrypto == NULL || s2n_libcrypto[0] == '\0') {
         END_TEST();
-        return 0;
     }
 
     if (strcmp(s2n_libcrypto, "default") == 0) {
         END_TEST();
     }
 
-    /* Ensure that FIPS mode is enabled when linked to AWS-LC-FIPS, and disabled when linked to AWS-LC */
-    if (strstr(s2n_libcrypto, "awslc") != NULL) {
-        s2n_fips_mode fips_mode = S2N_FIPS_MODE_DISABLED;
-        EXPECT_SUCCESS(s2n_get_fips_mode(&fips_mode));
-
-        if (strstr(s2n_libcrypto, "fips") != NULL) {
-            EXPECT_EQUAL(fips_mode, S2N_FIPS_MODE_ENABLED);
-        } else {
-            EXPECT_EQUAL(fips_mode, S2N_FIPS_MODE_DISABLED);
-        }
+    /* Ensure that FIPS mode is enabled only when linked to a fips library */
+    s2n_fips_mode fips_mode = S2N_FIPS_MODE_DISABLED;
+    EXPECT_SUCCESS(s2n_get_fips_mode(&fips_mode));
+    if (strstr(s2n_libcrypto, "fips") && !strstr(s2n_libcrypto, "1.0.2")) {
+        EXPECT_EQUAL(fips_mode, S2N_FIPS_MODE_ENABLED);
+    } else {
+        EXPECT_EQUAL(fips_mode, S2N_FIPS_MODE_DISABLED);
     }
 
     char s2n_libcrypto_copy[MAX_LIBCRYPTO_NAME_LEN] = { 0 };
@@ -150,7 +148,8 @@ int main()
     {
         if (strstr(name, "awslc") != NULL) {
             /* Early versions of awslc's SSLeay_version return an inaccurate value left over
-	     * after its fork from BoringSSL.  */
+             * after its fork from BoringSSL.
+             */
             EXPECT_TRUE(s2n_libcrypto_is_awslc());
         } else {
             /* Any other library should have the name of the library (modulo case) in its version string.  */
@@ -164,7 +163,15 @@ int main()
     {
         if (version != NULL) {
             const char *ssleay_version_text = SSLeay_version(SSLEAY_VERSION);
-            EXPECT_NOT_NULL(strstr(ssleay_version_text, version));
+            if (strstr(ssleay_version_text, version) == NULL) {
+                char fail_msg[256] = { 0 };
+                snprintf(
+                        fail_msg, sizeof(fail_msg),
+                        "Libcrypto version mismatch: expected version '%s' "
+                        "not found in actual libcrypto version string '%s'",
+                        version, ssleay_version_text);
+                FAIL_MSG(fail_msg);
+            }
         }
     };
 
@@ -178,5 +185,4 @@ int main()
     };
 
     END_TEST();
-    return 0;
 }
