@@ -17,7 +17,6 @@
 
 #include "crypto/s2n_pq.h"
 #include "crypto/s2n_rsa_pss.h"
-#include "crypto/s2n_rsa_signing.h"
 #include "s2n_test.h"
 #include "testlib/s2n_testlib.h"
 #include "tls/s2n_kem.h"
@@ -108,6 +107,9 @@ int main(int argc, char **argv)
     DEFER_CLEANUP(struct s2n_cert_chain_and_key *ecdsa_sha384_chain_and_key = NULL, s2n_cert_chain_and_key_ptr_free);
     EXPECT_SUCCESS(s2n_test_cert_permutation_load_server_chain(&ecdsa_sha384_chain_and_key, "ec", "ecdsa", "p384", "sha384"));
 
+    DEFER_CLEANUP(struct s2n_cert_chain_and_key *ecdsa_sha256_chain_and_key = NULL, s2n_cert_chain_and_key_ptr_free);
+    EXPECT_SUCCESS(s2n_test_cert_permutation_load_server_chain(&ecdsa_sha256_chain_and_key, "ec", "ecdsa", "p256", "sha256"));
+
     DEFER_CLEANUP(struct s2n_cert_chain_and_key *rsa_pss_chain_and_key = NULL, s2n_cert_chain_and_key_ptr_free);
     if (s2n_is_rsa_pss_certs_supported()) {
         EXPECT_SUCCESS(s2n_test_cert_chain_and_key_new(&rsa_pss_chain_and_key,
@@ -812,21 +814,46 @@ int main(int argc, char **argv)
          * breakage by verifying compatibility.
          */
         if (s2n_is_tls13_fully_supported()) {
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_tls13", ecdsa_sha384_chain_and_key));
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_fips", ecdsa_sha384_chain_and_key));
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "20250211", ecdsa_sha384_chain_and_key));
+            /* 20250211 */
+            {
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_tls13", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_fips", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "20250211", ecdsa_sha384_chain_and_key));
 
-            /* default_tls13 is currently 20240503 */
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "rfc9151", ecdsa_sha384_chain_and_key));
-            /* default_fips is currently 20240502 */
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240502, "rfc9151", ecdsa_sha384_chain_and_key));
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250211, "rfc9151", ecdsa_sha384_chain_and_key));
+                /* default_tls13 is currently 20240503 */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "rfc9151", ecdsa_sha384_chain_and_key));
+                /* default_fips is currently 20240502 */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240502, "rfc9151", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250211, "rfc9151", ecdsa_sha384_chain_and_key));
 
-            /* default_tls13 > 20250211
-             * note this does not require a sha384 key.
-             */
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "20250211", ecdsa_chain_and_key));
-            EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "default_tls13", ecdsa_chain_and_key));
+                /* default_tls13 > 20250211
+                */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "20250211", ecdsa_chain_and_key));
+
+                /* note this ended up requiring a sha384 key, fixed in 20250414. */
+                EXPECT_ERROR_WITH_ERRNO(s2n_test_security_policies_compatible(&security_policy_20240503, "20250211", ecdsa_sha256_chain_and_key),
+                        S2N_ERR_NO_VALID_SIGNATURE_SCHEME);
+            };
+
+            /* 20250414 */
+            {
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_tls13", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "default_fips", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_rfc9151, "20250414", ecdsa_sha384_chain_and_key));
+
+                /* default_tls13 is currently 20240503 */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "rfc9151", ecdsa_sha384_chain_and_key));
+                /* default_fips is currently 20240502 */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240502, "rfc9151", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250414, "rfc9151", ecdsa_sha384_chain_and_key));
+
+                /* default_tls13 > 20250414 (with either p-256 or p-384 cert) */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "20250414", ecdsa_sha384_chain_and_key));
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20240503, "20250414", ecdsa_sha256_chain_and_key));
+
+                /* 20250211 > 20250414 (with p-384 cert only) */
+                EXPECT_OK(s2n_test_security_policies_compatible(&security_policy_20250211, "20250414", ecdsa_sha384_chain_and_key));
+            };
         };
     };
 
@@ -904,16 +931,69 @@ int main(int argc, char **argv)
         EXPECT_SUCCESS(s2n_find_security_policy_from_version("default_tls13", &default_tls13));
         EXPECT_EQUAL(default_tls13->kem_preferences, &kem_preferences_null);
 
-        /* If we ignore kem preferences, the two policies match */
+        /* Except for PQ algorithms, the two policies should match */
+
+        /* Most fields can be compared directly. We just ignore kem_preferences. */
         EXPECT_EQUAL(default_pq->minimum_protocol_version, default_tls13->minimum_protocol_version);
         EXPECT_EQUAL(default_pq->cipher_preferences, default_tls13->cipher_preferences);
-        EXPECT_EQUAL(default_pq->signature_preferences, default_tls13->signature_preferences);
-        EXPECT_EQUAL(default_pq->certificate_signature_preferences,
-                default_tls13->certificate_signature_preferences);
         EXPECT_EQUAL(default_pq->ecc_preferences, default_tls13->ecc_preferences);
         EXPECT_EQUAL(default_pq->certificate_key_preferences, default_tls13->certificate_key_preferences);
         EXPECT_EQUAL(default_pq->certificate_preferences_apply_locally,
                 default_tls13->certificate_preferences_apply_locally);
+
+        /* The signature preferences match,
+         * EXCEPT for the added PQ algorithms, which should come first.
+         */
+        {
+            const struct s2n_signature_preferences *pq_sig_prefs = default_pq->signature_preferences;
+            const struct s2n_signature_preferences *tls13_sig_prefs = default_tls13->signature_preferences;
+
+            /* Count how many PQ sig schemes */
+            size_t pq_count = 0;
+            while (pq_count < pq_sig_prefs->count) {
+                if (pq_sig_prefs->signature_schemes[pq_count]->sig_alg
+                        == S2N_SIGNATURE_MLDSA) {
+                    pq_count++;
+                } else {
+                    break;
+                }
+            }
+            EXPECT_TRUE(pq_count > 0);
+
+            /* Compare the two preference lists, minus the PQ sig schemes */
+            EXPECT_EQUAL(pq_sig_prefs->count - pq_count, tls13_sig_prefs->count);
+            for (size_t i = 0; i < default_tls13->signature_preferences->count; i++) {
+                EXPECT_EQUAL(pq_sig_prefs->signature_schemes[i + pq_count],
+                        tls13_sig_prefs->signature_schemes[i]);
+            }
+        }
+
+        /* The certificate signature preferences match,
+         * EXCEPT for the added PQ algorithms, which should come first.
+         */
+        {
+            const struct s2n_signature_preferences *pq_sig_prefs = default_pq->certificate_signature_preferences;
+            const struct s2n_signature_preferences *tls13_sig_prefs = default_tls13->certificate_signature_preferences;
+
+            /* Count how many PQ sig schemes */
+            size_t pq_count = 0;
+            while (pq_count < pq_sig_prefs->count) {
+                if (pq_sig_prefs->signature_schemes[pq_count]->sig_alg
+                        == S2N_SIGNATURE_MLDSA) {
+                    pq_count++;
+                } else {
+                    break;
+                }
+            }
+            EXPECT_TRUE(pq_count > 0);
+
+            /* Compare the two preference lists, minus the PQ sig schemes */
+            EXPECT_EQUAL(pq_sig_prefs->count - pq_count, tls13_sig_prefs->count);
+            for (size_t i = 0; i < default_tls13->signature_preferences->count; i++) {
+                EXPECT_EQUAL(pq_sig_prefs->signature_schemes[i + pq_count],
+                        tls13_sig_prefs->signature_schemes[i]);
+            }
+        }
     };
 
     END_TEST();
